@@ -2317,7 +2317,7 @@ enum
 
 /* Define CC and CFLAGS which were used to build this version of GMP */
 #define __GMP_CC "gcc"
-#define __GMP_CFLAGS "-O2 -I/builder/x86_64/build/staging_dir/host/include "
+#define __GMP_CFLAGS "-O2 -I/home/uxgood/work/uxgood.github.com/openwrt/build-x86_64-18.06.4/staging_dir/host/include "
 
 /* Major version number is the value of __GNU_MP__ too, above. */
 #define __GNU_MP_VERSION            6
